@@ -6,6 +6,13 @@ import os
 import errno
 
 
+def is_root(ctx, param, value):
+    if os.geteuid() == 0:
+        return True
+    else:
+        raise click.BadParameter(f'You should run command from root user')
+
+
 def validate_url(ctx, param, value):
     if validators.url(value):
         return value
@@ -23,11 +30,14 @@ def update_config_file(new_config):
                 raise
 
     # Read file
-    with open(settings.PATH_TO_MS_CONFIG) as json_file:
-        if len(json_file.read()) >= 1:
-            data = json.load(json_file)
-        else:
-            data = {}
+    try:
+        with open(settings.PATH_TO_MS_CONFIG) as json_file:
+            if len(json_file.read()) >= 1:
+                data = json.loads(json_file.read())
+            else:
+                data = {}
+    except FileNotFoundError:
+        data = {}
 
     # Prepare config to insert
     unique_integration = f"{new_config['monitoring_system']}_{new_config['integration_name']}"
@@ -42,6 +52,7 @@ def update_config_file(new_config):
 
 
 @click.command()
+@click.option('--yes', is_flag=True, callback=is_root, expose_value=True, prompt='Are you running command from root?')
 @click.option("--monitoring-system", prompt="Choose monitoring system to configure", help="Monitoring system", type=click.Choice(['zabbix', 'icinga'], case_sensitive=False), required=True)
 @click.option("--integration-name", prompt="Choose unique name of your integration", help="Name of your integration", required=True)
 @click.option("--url", prompt="URL to your system (http://system-hostname)", help="http://system-hostname", required=True, callback=validate_url)
